@@ -3,7 +3,6 @@ use std::convert::Infallible;
 use std::error::Error as StdError;
 use std::fmt;
 
-use crate::http::StatusCode;
 use crate::{Depot, Request, Response, Writer};
 
 type BoxError = Box<dyn std::error::Error + Send + Sync>;
@@ -14,6 +13,7 @@ pub struct Error {
 }
 
 impl Error {
+    /// Create a new `Error`.
     #[inline]
     pub fn new<E: Into<BoxError>>(err: E) -> Error {
         Error { inner: err.into() }
@@ -41,11 +41,21 @@ impl From<Infallible> for Error {
     }
 }
 
+#[cfg(debug_assertions)]
 #[async_trait]
 impl Writer for Error {
     #[inline]
     async fn write(mut self, _req: &mut Request, _depot: &mut Depot, res: &mut Response) {
-        res.set_status_code(StatusCode::INTERNAL_SERVER_ERROR);
+        res.set_http_error(crate::http::errors::InternalServerError().with_detail(&self.to_string()));
+    }
+}
+
+#[cfg(not(debug_assertions))]
+#[async_trait]
+impl Writer for Error {
+    #[inline]
+    async fn write(mut self, _req: &mut Request, _depot: &mut Depot, res: &mut Response) {
+        res.set_status_code(crate::http::StatusCode::INTERNAL_SERVER_ERROR);
     }
 }
 
@@ -54,15 +64,21 @@ fn error_size_of() {
     assert_eq!(::std::mem::size_of::<Error>(), ::std::mem::size_of::<usize>() * 2);
 }
 
+#[cfg(debug_assertions)]
 #[cfg(feature = "anyhow")]
 #[async_trait]
 impl Writer for ::anyhow::Error {
     async fn write(mut self, _req: &mut Request, _depot: &mut Depot, res: &mut Response) {
-        res.set_http_error(
-            crate::http::errors::InternalServerError()
-                .with_summary("anyhow error message")
-                .with_detail(&self.to_string()),
-        );
+        res.set_http_error(crate::http::errors::InternalServerError().with_detail(&self.to_string()));
+    }
+}
+
+#[cfg(not(debug_assertions))]
+#[cfg(feature = "anyhow")]
+#[async_trait]
+impl Writer for ::anyhow::Error {
+    async fn write(mut self, _req: &mut Request, _depot: &mut Depot, res: &mut Response) {
+        res.set_http_error(crate::http::errors::InternalServerError());
     }
 }
 
@@ -75,23 +91,23 @@ mod tests {
     #[tokio::test]
     #[cfg(feature = "anyhow")]
     async fn test_anyhow() {
-        let mut request = Request::default();
-        let mut response = Response::default();
+        let mut req = Request::default();
+        let mut res = Response::default();
         let mut depot = Depot::new();
 
         let err: ::anyhow::Error = Error::new("detail message").into();
-        err.write(&mut request, &mut depot, &mut response).await;
-        assert_eq!(response.status_code(), Some(StatusCode::INTERNAL_SERVER_ERROR));
+        err.write(&mut req, &mut depot, &mut res).await;
+        assert_eq!(res.status_code(), Some(crate::http::StatusCode::INTERNAL_SERVER_ERROR));
     }
 
     #[tokio::test]
     async fn test_error() {
-        let mut request = Request::default();
-        let mut response = Response::default();
+        let mut req = Request::default();
+        let mut res = Response::default();
         let mut depot = Depot::new();
 
         let err = Error::new("detail message");
-        err.write(&mut request, &mut depot, &mut response).await;
-        assert_eq!(response.status_code(), Some(StatusCode::INTERNAL_SERVER_ERROR));
+        err.write(&mut req, &mut depot, &mut res).await;
+        assert_eq!(res.status_code(), Some(crate::http::StatusCode::INTERNAL_SERVER_ERROR));
     }
 }
