@@ -142,8 +142,9 @@ impl NamedFileBuilder {
                 let disposition_type = if attached_filename.is_some() {
                     "attachment"
                 } else {
-                    match content_type.type_() {
-                        mime::IMAGE | mime::TEXT | mime::VIDEO | mime::JAVASCRIPT | mime::JSON => "inline",
+                    match (content_type.type_(), content_type.subtype()) {
+                        (mime::IMAGE | mime::TEXT | mime::VIDEO | mime::AUDIO, _)
+                        | (_, mime::JAVASCRIPT | mime::JSON) => "inline",
                         _ => "attachment",
                     }
                 };
@@ -186,9 +187,9 @@ impl NamedFileBuilder {
 impl NamedFile {
     /// Create new `NamedFileBuilder`.
     #[inline]
-    pub fn builder(path: PathBuf) -> NamedFileBuilder {
+    pub fn builder(path: impl Into<PathBuf>) -> NamedFileBuilder {
         NamedFileBuilder {
-            path,
+            path: path.into(),
             attached_filename: None,
             disposition_type: None,
             content_type: None,
@@ -206,11 +207,11 @@ impl NamedFile {
     /// ```
     /// use salvo_core::fs::NamedFile;
     /// # async fn open() {
-    ///     let file = NamedFile::open("foo.txt".into()).await;
+    ///     let file = NamedFile::open("foo.txt").await;
     /// # }
     /// ```
     #[inline]
-    pub async fn open(path: PathBuf) -> crate::Result<NamedFile> {
+    pub async fn open(path: impl Into<PathBuf>) -> crate::Result<NamedFile> {
         Self::builder(path).build().await
     }
 
@@ -228,7 +229,7 @@ impl NamedFile {
     /// # use std::io;
     /// # use salvo_core::fs::NamedFile;
     /// # async fn path() {
-    ///     let file = NamedFile::open("test.txt".into()).await.unwrap();
+    ///     let file = NamedFile::open("test.txt").await.unwrap();
     ///     assert_eq!(file.path().as_os_str(), "foo.txt");
     /// # }
     /// ```
