@@ -2,7 +2,7 @@
 
 use std::borrow::Cow;
 use std::error::Error as StdError;
-use std::fmt::{self, Debug};
+use std::fmt;
 use std::pin::Pin;
 use std::task::{self, Poll};
 
@@ -461,7 +461,7 @@ impl Response {
     }
 }
 
-impl Debug for Response {
+impl fmt::Debug for Response {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         writeln!(
             f,
@@ -474,7 +474,7 @@ impl Debug for Response {
 
 impl fmt::Display for Response {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        Debug::fmt(self, f)
+        fmt::Debug::fmt(self, f)
     }
 }
 
@@ -511,8 +511,8 @@ mod test {
     #[tokio::test]
     async fn test_body_stream2() {
         let mut body = Body::Stream(Box::pin(iter(vec![
-            Result::<_, Box<dyn Error + Send + Sync>>::Ok(BytesMut::from("hello").freeze()),
-            Result::<_, Box<dyn Error + Send + Sync>>::Ok(BytesMut::from(" world").freeze()),
+            Result::<_, Box<dyn Error + Send + Sync>>::Ok(BytesMut::from("Hello").freeze()),
+            Result::<_, Box<dyn Error + Send + Sync>>::Ok(BytesMut::from(" World").freeze()),
         ])));
 
         let mut result = bytes::BytesMut::new();
@@ -520,7 +520,7 @@ mod test {
             result.extend_from_slice(&data)
         }
 
-        assert_eq!("hello world", &result)
+        assert_eq!("Hello World", &result)
     }
     #[tokio::test]
     async fn test_others() {
