@@ -213,17 +213,6 @@ impl RustlsConfig {
             }
         };
 
-        fn read_trust_anchor(trust_anchor: Box<dyn Read + Send + Sync>) -> Result<RootCertStore, Error> {
-            let mut reader = BufReader::new(trust_anchor);
-            let certs = rustls_pemfile::certs(&mut reader).map_err(|_| Error::RsaParseError)?;
-            let mut store = RootCertStore::empty();
-            if let (0, _) = store.add_parsable_certificates(&certs) {
-                Err(Error::CertParseError)
-            } else {
-                Ok(store)
-            }
-        }
-
         let client_auth = match self.client_auth {
             TlsClientAuth::Off => NoClientAuth::new(),
             TlsClientAuth::Optional(trust_anchor) => {
@@ -244,6 +233,17 @@ impl RustlsConfig {
     }
 }
 
+fn read_trust_anchor(trust_anchor: Box<dyn Read + Send + Sync>) -> Result<RootCertStore, Error> {
+    let mut reader = BufReader::new(trust_anchor);
+    let certs = rustls_pemfile::certs(&mut reader).map_err(|_| Error::RsaParseError)?;
+    let mut store = RootCertStore::empty();
+    if let (0, _) = store.add_parsable_certificates(&certs) {
+        Err(Error::CertParseError)
+    } else {
+        Ok(store)
+    }
+}
+
 pin_project! {
     /// RustlsListener
     #[cfg_attr(docsrs, doc(cfg(feature = "rustls")))]
@@ -280,6 +280,12 @@ where
     }
 }
 
+impl<C> RustlsListener<C> {
+    /// Get local address
+    pub fn local_addr(&self) -> SocketAddr {
+        self.incoming.local_addr().into()
+    }
+}
 impl RustlsListener<stream::Once<Ready<Arc<ServerConfig>>>> {
     /// Create new RustlsListenerBuilder with RustlsConfig.
     #[inline]
@@ -344,9 +350,9 @@ where
                 *this.server_config = Some(config.into());
             }
         }
-        if let Some(server_config) = this.server_config.clone() {
+        if let Some(server_config) = &this.server_config {
             match ready!(Pin::new(this.incoming).poll_accept(cx)) {
-                Some(Ok(sock)) => Poll::Ready(Some(Ok(RustlsStream::new(sock, server_config)))),
+                Some(Ok(sock)) => Poll::Ready(Some(Ok(RustlsStream::new(sock, server_config.clone())))),
                 Some(Err(e)) => Poll::Ready(Some(Err(e))),
                 None => Poll::Ready(None),
             }
@@ -358,6 +364,17 @@ where
         }
     }
 }
+impl<C> Future for RustlsListener<C>
+where
+    C: Stream,
+    C::Item: Into<Arc<ServerConfig>>,
+{
+    type Output = Option<Result<RustlsStream, io::Error>>;
+
+    fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
+        self.poll_accept(cx)
+    }
+}
 
 enum RustlsState {
     Handshaking(tokio_rustls::Accept<AddrStream>),
@@ -439,26 +456,48 @@ impl AsyncWrite for RustlsStream {
 
 #[cfg(test)]
 mod tests {
+    use tokio::io::{AsyncReadExt, AsyncWriteExt};
+    use tokio::net::TcpStream;
+    use tokio_rustls::rustls::{ClientConfig, ServerName};
+    use tokio_rustls::TlsConnector;
+
     use super::*;
 
     #[test]
-    fn file_cert_key() {
+    fn test_file_cert_key() {
         RustlsConfig::new()
-            .with_key_path("../examples/tls/key.rsa")
-            .with_cert_path("../examples/tls/cert.pem")
+            .with_key_path("../examples/certs/end.rsa")
+            .with_cert_path("../examples/certs/end.cert")
             .build_server_config()
             .unwrap();
     }
 
-    #[test]
-    fn bytes_cert_key() {
-        let key = include_str!("../../../examples/tls/key.rsa");
-        let cert = include_str!("../../../examples/tls/cert.pem");
+    #[tokio::test]
+    async fn test_rustls_listener() {
+        let addr = std::net::SocketAddr::from(([127, 0, 0, 1], 7978));
+        let listener = RustlsListener::with_rustls_config(
+            RustlsConfig::new()
+                .with_key_path("../examples/certs/end.rsa")
+                .with_cert_path("../examples/certs/end.cert"),
+        )
+        .bind(addr);
 
-        RustlsConfig::new()
-            .with_key(key.as_bytes())
-            .with_cert(cert.as_bytes())
-            .build_server_config()
-            .unwrap();
+        tokio::spawn(async move {
+            let stream = TcpStream::connect(addr).await.unwrap();
+            let trust_anchor = include_bytes!("../../../examples/certs/end.chain");
+            let client_config = ClientConfig::builder()
+                .with_safe_defaults()
+                .with_root_certificates(read_trust_anchor(Box::new(trust_anchor.as_slice())).unwrap())
+                .with_no_client_auth();
+            let connector = TlsConnector::from(Arc::new(client_config));
+            let mut tls_stream = connector
+                .connect(ServerName::try_from("testserver.com").unwrap(), stream)
+                .await
+                .unwrap();
+            tls_stream.write_i32(518).await.unwrap();
+        });
+
+        let mut stream = listener.await.unwrap().unwrap();
+        assert_eq!(stream.read_i32().await.unwrap(), 518);
     }
 }
