@@ -1,3 +1,5 @@
+use std::fmt;
+
 use crate::http::{Method, Request};
 use crate::routing::{Filter, PathState};
 
@@ -11,3 +13,9 @@ impl Filter for MethodFilter {
         req.method() == self.0
     }
 }
+
+impl fmt::Debug for MethodFilter {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "[{:?}]", self.0)
+    }
+}
